@@ -70,10 +70,10 @@ def gitDescribeToPep440(version):
         if v.group('dev'):
             patch += 1
             dev = int(v.group('dev'))
-            return "{}.{}.{}.dev{}".format(major, minor, patch, dev)
+            return f"{major}.{minor}.{patch}.dev{dev}"
         if v.group('post'):
             return "{}.{}.{}.post{}".format(major, minor, patch, v.group('post'))
-        return "{}.{}.{}".format(major, minor, patch)
+        return f"{major}.{minor}.{patch}"
 
     return v
 
@@ -88,29 +88,29 @@ def mTimeVersion(init_file):
     return d.strftime("%Y.%m.%d")
 
 
-def getVersionFromArchiveId(git_archive_id='$Format:%ct %d$'):
+def getVersionFromArchiveId(git_archive_id='$Format:%ct %(describe:abbrev=10)$'):
     """Extract the tag if a source is from git archive.
 
     When source is exported via `git archive`, the git_archive_id init value is modified
     and placeholders are expanded to the "archived" revision:
 
         %ct: committer date, UNIX timestamp
-        %d: ref names, like the --decorate option of git-log
+        %(describe:abbrev=10): git-describe output, always abbreviating to 10 characters of commit ID.
+                               e.g. v3.10.0-850-g5bf957f89
 
     See man gitattributes(5) and git-log(1) (PRETTY FORMATS) for more details.
     """
     # mangle the magic string to make sure it is not replaced by git archive
-    if not git_archive_id.startswith('$Format:'):
+    if not git_archive_id.startswith('$For' + 'mat:'):
         # source was modified by git archive, try to parse the version from
         # the value of git_archive_id
 
-        match = re.search(r'tag:\s*v([^,)]+)', git_archive_id)
-        if match:
+        tstamp, _, describe_output = git_archive_id.strip().partition(' ')
+        if describe_output:
             # archived revision is tagged, use the tag
-            return gitDescribeToPep440(match.group(1))
+            return gitDescribeToPep440(describe_output)
 
         # archived revision is not tagged, use the commit date
-        tstamp = git_archive_id.strip().split()[0]
         d = datetime.datetime.fromtimestamp(int(tstamp), datetime.timezone.utc)
         return d.strftime('%Y.%m.%d')
     return None
@@ -132,7 +132,7 @@ def getVersion(init_file):
         fn = os.path.join(cwd, 'VERSION')
         with open(fn) as f:
             return f.read().strip()
-    except IOError:
+    except OSError:
         pass
 
     version = getVersionFromArchiveId()
@@ -230,7 +230,12 @@ class BuildJsCommand(Command):
 
             for command in commands:
                 logging.info('Running command: {}'.format(str(" ".join(command))))
-                subprocess.check_call(command, shell=shell)
+                try:
+                    subprocess.check_call(command, shell=shell)
+                except subprocess.CalledProcessError as e:
+                    raise Exception(
+                        f"Exception = {e} command was called in directory = {os.getcwd()}"
+                    ) from e
 
         self.copy_tree(
             os.path.join(package, 'static'), os.path.join("build", "lib", package, "static")
